===========
What's new?
===========

zfit is still under active development and may changes frequently, staying updated is recommended.

Recent changes in the newest version :ref:`newest-changelog`.

**Recommended:** Newest upgrade guide with zfit 0.20+, `run interactively and downloaded in the tutorials <https://zfit-tutorials.readthedocs.io/en/latest/tutorials/introduction/upgrade_guide_020.html>`_.

.. toctree::
    :maxdepth: 2

    ../_tmp/zfit-tutorials/introduction/upgrade_guide_020.ipynb
    changelog
